/// <reference types="node" />
import { DeepClient, DeepClientPathItem, DeepClientStartItem, Id, Link, QueryLink } from '@deep-foundation/deeplinks';
import { Subscription, Query } from '@deep-foundation/deeplinks/imports/client.js';
import EventEmitter from 'events';
import React, { Context } from 'react';
import { HandlerConfigContext } from './client-handler.js';
import { useCookiesStore } from '@deep-foundation/store/cookies.js';
import { useLocalStore } from '@deep-foundation/store/local.js';
import { useQueryStore } from '@deep-foundation/store/query.js';
import { getChakraVar, useChakraColor, useLoader } from './hooks.js';
export type onEnterI = (link: Link<Id>) => void;
export type onChangeI = (link: Link<Id>) => void;
export type PathI = string;
export interface GoI {
    _i: number;
    __p: number;
    (path?: PathI): GoI | null;
    linkId: Id;
    link?: Link<Id>;
    value: Id;
    current: GoI;
    deep: DeepClient<any>;
    path: string;
    do: DoI;
    focus?: FocusI;
    set?: FocusI;
    parents: ParentsI;
    parent: typeof parent;
    focused: typeof focused;
    log: typeof log;
    scroll: typeof scroll;
    toString: typeof toString;
    save: typeof save;
    Save: typeof Save;
    root: typeof root;
    await: typeof _await;
    awaitRef: typeof _awaitRef;
    all: AllI;
    go?: GoI;
    _go: typeof _go;
    __go?: GoI;
    __actualGoRef?: {
        current: GoI;
    };
    emitter: EventEmitter;
    children?: {
        [key: string]: GoI;
    };
    ref?: {
        current: any;
    };
    useGo: typeof useGo;
    useNav: typeof useNav;
    Provider: typeof GoProvider;
    Input: typeof Input;
    Editor: any;
    Handler: typeof Handler;
    Subscription: typeof Subscription;
    useLocalStore: typeof useLocalStore;
    useQueryStore: typeof useQueryStore;
    useCookiesStore: typeof useCookiesStore;
    getChakraVar: typeof getChakraVar;
    useChakraColor: typeof useChakraColor;
    HandlerConfigContext: typeof HandlerConfigContext;
    Component: typeof Component;
    Button: typeof Button;
    useHook: typeof useHook;
    Query: typeof Query;
    useLoader: typeof useLoader;
    loader: (query: any) => any;
    On: typeof On;
    on: typeof _on;
    emit: typeof emit;
    noScrollBar: typeof noScrollBar;
    context: GoContextI;
    activator: typeof activator;
    next: typeof next;
    prev: typeof prev;
    delay: typeof delay;
    useRefValue: typeof useRefValue;
    _focus?: any;
    _setValue?: any;
    hgo?: GoI;
    data?: {
        [key: string]: any;
    };
    componentTemplate: typeof componentTemplate;
    hookTemplate: typeof hookTemplate;
    [key: string]: any;
}
export interface GoCallbackI {
    (go: GoI): any;
}
export interface FocusI {
    (value: Id, ...args: any[]): {
        go: GoI;
        data?: Promise<any> | any;
    };
}
export interface ParentsI {
    (): GoI[];
}
export interface AllI {
    (path: string): {
        steps: Id[];
        data: GoI[];
    };
}
export interface DoI {
    (...args: any[]): {
        data?: Promise<any>;
        go: GoI;
    };
}
export interface DoHandleI {
    (go: any, value: Id, ...args: any[]): any | Promise<any>;
}
export type onDoI = onDoObjectI | DoHandleI;
export interface onDoObjectI {
    [name: string]: DoHandleI;
}
export declare const GoCustomContext: React.Context<any>;
export declare function GoCustomProvider({ value, children }: {
    value: any;
    children?: any;
}): React.JSX.Element;
export type GoContextI = Context<GoI | undefined>;
export declare const GoContext: GoContextI;
export declare function useGoCore(context?: GoContextI): GoI;
export declare const ValueContext: React.Context<any>;
export declare const GoEditorContext: React.Context<any>;
export declare const GoEditorProvider: React.NamedExoticComponent<{
    Editor: any;
    children: any;
}>;
export declare const GoProvider: React.NamedExoticComponent<{
    linkId?: Id;
    value?: Id;
    on?: {
        [name: string]: onDoI;
    };
    context?: GoContextI;
    children?: any;
    hotkeys?: boolean;
}>;
declare const On: (on: any) => any;
declare const delay: (time: any) => Promise<unknown>;
declare function useRefValue(value: any): React.MutableRefObject<any>;
declare const _on: (name: any, value: any, handler: any, onsRef: any) => {
    go: any;
    emitter: any;
    name: any;
    value: any;
    listener: (g: any, v: any, ...args: any[]) => void;
    off: () => any;
};
declare const emit: (name: any, value: any, ...args: any[]) => boolean;
declare const parent: (id: any) => GoI | undefined;
export declare function useGo(): GoI;
declare function activator(state: [any, React.Dispatch<React.SetStateAction<any>>], mustbe: any, ifthen?: string, elsethen?: any, prop?: string): {
    [x: string]: any;
    onClick: () => void;
    children: any;
};
declare function prev(list: any): any;
declare function next(list: any): any;
interface NavI {
    (name: Id, left: Id, up: Id, right: Id, down: Id): void;
    get?: (from: Id, to: Id) => Id;
    map?: {
        [key: Id]: {
            name: Id;
            left: Id;
            up: Id;
            right: Id;
            down: Id;
        };
    };
}
declare function useNav(): NavI;
declare function root(): any;
declare function focused(): any[];
declare function log(value: string): void;
declare function scroll(options?: any): {
    go: any;
};
declare function _go(path?: PathI | GoCallbackI): GoI;
declare function toString(): string;
declare function Save({ handlerId }: {
    handlerId: any;
}): void;
declare function _await(id: any): Promise<unknown>;
declare function _awaitRef(id: any): Promise<unknown>;
declare function save(handlerId: any): Promise<any>;
export declare const noScrollBar: {
    '&::-webkit-scrollbar': {
        display: string;
    };
    '&::-webkit-scrollbar-track': {
        display: string;
    };
    '&::-webkit-scrollbar-thumb': {
        display: string;
    };
    'scrollbar-width': string;
};
declare const componentTemplate: {
    ({ children }?: {
        children: any;
    }): string;
    toString(): string;
};
declare const hookTemplate: {
    (): string;
    toString(): string;
};
declare const useHook: ({ path, extendInsert, postfix }: {
    path: any;
    extendInsert?: {};
    postfix?: string;
}) => any;
declare const Handler: React.NamedExoticComponent<{
    [key: string]: any;
    provide?: boolean;
    handlerId?: Id;
    linkId?: Id;
    on?: any;
}>;
declare const Component: React.NamedExoticComponent<{
    [key: string]: any;
    path: [Id, ...Id[]];
    linkId?: Id;
    extendInsert?: any;
    provide?: boolean;
    on?: any;
}>;
declare const Button: React.NamedExoticComponent<any>;
declare const Input: React.MemoExoticComponent<({ path, insert, title, type, ...props }: {
    [key: string]: any;
    path: [DeepClientStartItem | QueryLink, ...DeepClientPathItem[]];
    insert?: any;
    title?: any;
    type?: 'string' | 'number';
}) => React.JSX.Element>;
export {};
