var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DeepClient } from '@deep-foundation/deeplinks';
import axios from 'axios';
let _path, _ssl = true;
try {
    _path = process.env.GQL || process.env.NEXT_PUBLIC_GRAPHQL_URL || 'https://deeplinks.deep.foundation/gql';
}
catch (e) { }
try {
    _ssl = new URL(_path).protocol === "https:";
}
catch (e) { }
_path = _path.replace(/(^\w+:|^)\/\//, '');
const _secret = process.env.SECRET || process.env.DEEPLINKS_HASURA_SECRET;
const _token = process.env.TOKEN || process.env.NEXT_PUBLIC_DEEP_TOKEN;
export function preloadQueries(deep) {
    return __awaiter(this, void 0, void 0, function* () {
        const packagesQ = {
            type_id: {
                _nin: [
                    deep.idLocal('@deep-foundation/core', 'Promise'),
                    deep.idLocal('@deep-foundation/core', 'Then'),
                    deep.idLocal('@deep-foundation/core', 'Rejected'),
                    deep.idLocal('@deep-foundation/core', 'Resolved'),
                    deep.idLocal('@deep-foundation/core', 'PromiseResult'),
                    yield deep.id('@deep-foundation/tsx', 'TSX'),
                ]
            },
            up: {
                tree_id: { _eq: deep.idLocal('@deep-foundation/core', 'containTree') },
                parent: {
                    type_id: { _eq: deep.idLocal('@deep-foundation/core', 'Package') },
                    string: { value: { _neq: 'deep' } },
                },
            },
            return: {
                _version: {
                    relation: 'in',
                    type_id: deep.idLocal('@deep-foundation/core', 'PackageVersion')
                },
            },
        };
        const packagesO = { apply: 'packages' };
        const handlersQ = {
            execution_provider_id: { _eq: deep.idLocal('@deep-foundation/core', 'JSExecutionProvider') },
            return: {
                dist: { relation: 'dist' }
            },
        };
        const handlersO = { table: 'handlers' };
        return { packagesQ, packagesO, handlersQ, handlersO, };
    });
}
export function preloadApi(path = _path, secret = _secret, token = _token, ssl = _ssl) {
    return __awaiter(this, void 0, void 0, function* () {
        const p = path.replace(/(^\w+:|^)\/\//, '');
        const deep = new DeepClient({
            path: p,
            ssl: ssl,
            secret: secret,
            token: token,
            ws: true,
        });
        const preloaded = {
            packages: [],
            handlers: [],
        };
        const { packagesQ, packagesO, handlersQ, handlersO } = yield preloadQueries(deep);
        deep.subscribe(packagesQ, packagesO).subscribe({
            next: ({ plainLinks: packages }) => {
                preloaded.packages = packages;
            },
        });
        deep.subscribe(handlersQ, handlersO).subscribe({
            next: ({ data: handlers }) => {
                preloaded.handlers = handlers;
            },
        });
        let initial = true;
        return function handler(req, res) {
            var _a, _b;
            return __awaiter(this, void 0, void 0, function* () {
                if (initial) {
                    preloaded.packages = (_a = (yield deep.select(packagesQ, packagesO))) === null || _a === void 0 ? void 0 : _a.plainLinks;
                    preloaded.handlers = (_b = (yield deep.select(handlersQ, handlersO))) === null || _b === void 0 ? void 0 : _b.data;
                    initial = false;
                }
                console.log('preloadApi', { packages: preloaded.packages.length, handlers: preloaded.handlers.length });
                res.status(200).json(preloaded);
            });
        };
    });
}
export function getServerSidePropsPreload(arg, result) {
    return __awaiter(this, void 0, void 0, function* () {
        const preload = yield axios.get(`${process.env.__NEXT_PRIVATE_ORIGIN}/api/preload`);
        result.props = (result === null || result === void 0 ? void 0 : result.props) || {};
        result.props.preloaded = preload.data;
        console.log('getServerSidePropsPreload', { packages: preload.data.packages.length, handlers: preload.data.handlers.length });
        return result;
    });
}
//# sourceMappingURL=preload.js.map